@@ -26,14 +26,14 @@ class CancelHandshakeRequest(RpcRequest):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'CancelHandshake')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_HandshakeId(self):
+	def get_HandshakeId(self): # String
 		return self.get_query_params().get('HandshakeId')
 
-	def set_HandshakeId(self,HandshakeId):
-		self.add_query_param('HandshakeId',HandshakeId)
\ No newline at end of file
+	def set_HandshakeId(self, HandshakeId):  # String
+		self.add_query_param('HandshakeId', HandshakeId)
