@@ -26,26 +26,24 @@ class CreatePolicyRequest(RpcRequest):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'CreatePolicy')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Description(self):
+	def get_Description(self): # String
 		return self.get_query_params().get('Description')
 
-	def set_Description(self,Description):
-		self.add_query_param('Description',Description)
-
-	def get_PolicyName(self):
+	def set_Description(self, Description):  # String
+		self.add_query_param('Description', Description)
+	def get_PolicyName(self): # String
 		return self.get_query_params().get('PolicyName')
 
-	def set_PolicyName(self,PolicyName):
-		self.add_query_param('PolicyName',PolicyName)
-
-	def get_PolicyDocument(self):
+	def set_PolicyName(self, PolicyName):  # String
+		self.add_query_param('PolicyName', PolicyName)
+	def get_PolicyDocument(self): # String
 		return self.get_query_params().get('PolicyDocument')
 
-	def set_PolicyDocument(self,PolicyDocument):
-		self.add_query_param('PolicyDocument',PolicyDocument)
\ No newline at end of file
+	def set_PolicyDocument(self, PolicyDocument):  # String
+		self.add_query_param('PolicyDocument', PolicyDocument)
