@@ -25,14 +25,14 @@ class DeleteServiceLinkedRoleRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'DeleteServiceLinkedRole')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RoleName(self):
+	def get_RoleName(self): # String
 		return self.get_query_params().get('RoleName')
 
-	def set_RoleName(self,RoleName):
-		self.add_query_param('RoleName',RoleName)
\ No newline at end of file
+	def set_RoleName(self, RoleName):  # String
+		self.add_query_param('RoleName', RoleName)
