@@ -25,14 +25,14 @@ class GetServiceLinkedRoleDeletionStatusRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'GetServiceLinkedRoleDeletionStatus')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DeletionTaskId(self):
+	def get_DeletionTaskId(self): # String
 		return self.get_query_params().get('DeletionTaskId')
 
-	def set_DeletionTaskId(self,DeletionTaskId):
-		self.add_query_param('DeletionTaskId',DeletionTaskId)
\ No newline at end of file
+	def set_DeletionTaskId(self, DeletionTaskId):  # String
+		self.add_query_param('DeletionTaskId', DeletionTaskId)
