@@ -26,26 +26,33 @@ class InviteAccountToResourceDirectoryRequest(RpcRequest):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'InviteAccountToResourceDirectory')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Note(self):
+	def get_Note(self): # String
 		return self.get_query_params().get('Note')
 
-	def set_Note(self,Note):
-		self.add_query_param('Note',Note)
-
-	def get_TargetType(self):
+	def set_Note(self, Note):  # String
+		self.add_query_param('Note', Note)
+	def get_TargetType(self): # String
 		return self.get_query_params().get('TargetType')
 
-	def set_TargetType(self,TargetType):
-		self.add_query_param('TargetType',TargetType)
+	def set_TargetType(self, TargetType):  # String
+		self.add_query_param('TargetType', TargetType)
+	def get_Tag(self): # Array
+		return self.get_query_params().get('Tag')
 
-	def get_TargetEntity(self):
+	def set_Tag(self, Tag):  # Array
+		for index1, value1 in enumerate(Tag):
+			if value1.get('Value') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Value', value1.get('Value'))
+			if value1.get('Key') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Key', value1.get('Key'))
+	def get_TargetEntity(self): # String
 		return self.get_query_params().get('TargetEntity')
 
-	def set_TargetEntity(self,TargetEntity):
-		self.add_query_param('TargetEntity',TargetEntity)
\ No newline at end of file
+	def set_TargetEntity(self, TargetEntity):  # String
+		self.add_query_param('TargetEntity', TargetEntity)
