@@ -26,14 +26,14 @@ class ListAncestorsRequest(RpcRequest):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'ListAncestors')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ChildId(self):
+	def get_ChildId(self): # String
 		return self.get_query_params().get('ChildId')
 
-	def set_ChildId(self,ChildId):
-		self.add_query_param('ChildId',ChildId)
\ No newline at end of file
+	def set_ChildId(self, ChildId):  # String
+		self.add_query_param('ChildId', ChildId)
