@@ -25,14 +25,14 @@ class ListDelegatedServicesForAccountRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'ListDelegatedServicesForAccount')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AccountId(self):
+	def get_AccountId(self): # String
 		return self.get_query_params().get('AccountId')
 
-	def set_AccountId(self,AccountId):
-		self.add_query_param('AccountId',AccountId)
\ No newline at end of file
+	def set_AccountId(self, AccountId):  # String
+		self.add_query_param('AccountId', AccountId)
