@@ -26,20 +26,19 @@ class MoveAccountRequest(RpcRequest):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'MoveAccount')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AccountId(self):
+	def get_AccountId(self): # String
 		return self.get_query_params().get('AccountId')
 
-	def set_AccountId(self,AccountId):
-		self.add_query_param('AccountId',AccountId)
-
-	def get_DestinationFolderId(self):
+	def set_AccountId(self, AccountId):  # String
+		self.add_query_param('AccountId', AccountId)
+	def get_DestinationFolderId(self): # String
 		return self.get_query_params().get('DestinationFolderId')
 
-	def set_DestinationFolderId(self,DestinationFolderId):
-		self.add_query_param('DestinationFolderId',DestinationFolderId)
\ No newline at end of file
+	def set_DestinationFolderId(self, DestinationFolderId):  # String
+		self.add_query_param('DestinationFolderId', DestinationFolderId)
