@@ -26,14 +26,14 @@ class ResendCreateCloudAccountEmailRequest(RpcRequest):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'ResendCreateCloudAccountEmail')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RecordId(self):
+	def get_RecordId(self): # String
 		return self.get_query_params().get('RecordId')
 
-	def set_RecordId(self,RecordId):
-		self.add_query_param('RecordId',RecordId)
\ No newline at end of file
+	def set_RecordId(self, RecordId):  # String
+		self.add_query_param('RecordId', RecordId)
