@@ -26,26 +26,24 @@ class UpdateAccountRequest(RpcRequest):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'UpdateAccount')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_NewDisplayName(self):
+	def get_NewDisplayName(self): # String
 		return self.get_query_params().get('NewDisplayName')
 
-	def set_NewDisplayName(self,NewDisplayName):
-		self.add_query_param('NewDisplayName',NewDisplayName)
-
-	def get_NewAccountType(self):
+	def set_NewDisplayName(self, NewDisplayName):  # String
+		self.add_query_param('NewDisplayName', NewDisplayName)
+	def get_NewAccountType(self): # String
 		return self.get_query_params().get('NewAccountType')
 
-	def set_NewAccountType(self,NewAccountType):
-		self.add_query_param('NewAccountType',NewAccountType)
-
-	def get_AccountId(self):
+	def set_NewAccountType(self, NewAccountType):  # String
+		self.add_query_param('NewAccountType', NewAccountType)
+	def get_AccountId(self): # String
 		return self.get_query_params().get('AccountId')
 
-	def set_AccountId(self,AccountId):
-		self.add_query_param('AccountId',AccountId)
\ No newline at end of file
+	def set_AccountId(self, AccountId):  # String
+		self.add_query_param('AccountId', AccountId)
